@@ -6,8 +6,8 @@ sandbox.configure({
       if (this.filename.indexOf("node_modules") > -1) {
         return source;
       }
-      const nyc = new (require("nyc"))();
-      return nyc.instrumenter().instrumentSync(source, this.filename);
+      const nyc = new (require("nyc"))({});
+      return nyc.instrumenter().instrumentSync(source, this.filename, { registerMap: () => {} });
     }
   }
 });
